#
# spec file for package python-ipyvuetify
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define distversion 1.10
Name:           python-ipyvuetify
Version:        1.10.0
Release:        1.1
Summary:        Jupyter widgets based on vuetify UI components
License:        MIT
URL:            https://github.com/mariobuikhuizen/ipyvuetify
Source0:        https://files.pythonhosted.org/packages/source/i/ipyvuetify/ipyvuetify-%{version}.tar.gz
Source1:        https://github.com/widgetti/ipyvuetify/raw/v%{version}/examples/Examples.ipynb
# TODO: Use local-npm-registry  https://github.com/openSUSE/obs-service-node_modules
# This would first require the generate_source step, then the npm build step
BuildRequires:  %{python_module jupyterlab >= 4}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
Requires:       (python-ipyvue >= 1.7 with python-ipyvue < 2)
Recommends:     jupyter-ipyvuetify-nbextension = %{version}
Recommends:     jupyter-jupyterlab-ipyvuetify = %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ipyvue >= 1.7 with %python-ipyvue < 2}
BuildRequires:  %{python_module nbval}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Jupyter widgets based on vuetify UI components

%package     -n jupyter-ipyvuetify-nbextension
Summary:        Jupyter widgets based on vuetify UI components - nbextension
Requires:       jupyter-notebook
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(ipyvuetify) = %{distversion}
Suggests:       python3-ipyvuetify

%description -n jupyter-ipyvuetify-nbextension
Jupyter widgets based on vuetify UI components

This package provides the jupyter notebook extension.

%package     -n jupyter-jupyterlab-ipyvuetify
Summary:        Jupyter widgets based on vuetify UI components - labextension
Requires:       jupyter-jupyterlab
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(ipyvuetify) = %{distversion}
Suggests:       python3-ipyvuetify

%description -n jupyter-jupyterlab-ipyvuetify
Jupyter widgets based on vuetify UI components

This package provides the jupyterlab extension.

%prep
%autosetup -p1 -n ipyvuetify-%{version}
chmod -x prefix/share/jupyter/labextensions/jupyter-vuetify/package.json \
         prefix/etc/nbconfig/notebook.d/jupyter-vuetify.json \
         README.md

%build
%pyproject_wheel

%install
%pyproject_install
%jupyter_move_config
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_jupyter_prefix}

%check
%pytest --nbval %{SOURCE1}

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/ipyvuetify
%{python_sitelib}/ipyvuetify-%{version}.dist-info

%files -n jupyter-ipyvuetify-nbextension
%license LICENSE
%_jupyter_config %{_jupyter_nb_notebook_confdir}/jupyter-vuetify.json
%{_jupyter_nbextension_dir}/jupyter-vuetify

%files -n jupyter-jupyterlab-ipyvuetify
%license LICENSE
%{_jupyter_labextensions_dir3}/jupyter-vuetify

%changelog
* Sun Sep 15 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.10.0
  * Jupyter Lab 4 support
- Drop avoidnpm.patch
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.9.1
  * fix: dark_effective should always be set, even when dark ==
    null
- Release 1.9.0
  * feat: improve dark detection and add dark_effective (#296)
  * fix: theme initialisation with Voilà lab template (#196)
- Add avoidnpm.patch
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19 (through
  ipyvue)
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Suggest primary python package -- boo#1214354
* Tue Jun 13 2023 Ben Greiner <code@bnavigator.de>
- Unpin jupyterlab build requirement
* Mon May  1 2023 Ben Greiner <code@bnavigator.de>
- Fix type on recommends
* Mon Apr 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.8.10
  * no upstreeam changelog provided (gh#widgetti/ipyvuetify#247)
* Tue Apr  4 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.8.7
  * no upstreeam changelog provided (gh#widgetti/ipyvuetify#247)
* Fri Feb  3 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile
- Required by ipyvolume 0.6
